//------------------------------------------------------------------------------
// <copyright company="Kartones.Net">
//     Copyleft (c) Kartones 2009
// </copyright> 
//------------------------------------------------------------------------------

using System;
using System.Xml;
using System.Collections.Generic;
using CommunityServer.Components;
using CommunityServer.Blogs.Components;

namespace KartonesNet.Modules
{
    /// <summary>
    /// DiggIt Module. Adds a DiggIt button and counter at the bottom of each post.
    /// </summary>
    public class DiggItAddon : ICSModule
    {
        #region Fields

        /// <summary>
        /// If we want to show the DiggIt button when syndicating
        /// </summary>
        private bool showInRSS = true;
        /// <summary>
        /// If we want to show the DiggIt button when rendering to web
        /// </summary>
        private bool showInWebPost = true;
        /// <summary>
        /// DiggIt skin to render (normal or compact)
        /// </summary>
        private string diggSkinMode = "compact";
        /// <summary>
        /// background color for the DiggIt skin (CSS valid color)
        /// </summary>
        private string backColor = "transparent";

        #endregion

        #region Class Constructor

        /// <summary>
        /// Class Constructor
        /// </summary>
        public DiggItAddon()
		{
        }

        #endregion

        #region Public ICSModule Methods

        /// <summary>
        /// Init Method. Called by CS when starting the module
        /// </summary>
        /// <param name="CSApp">CS Application starting the module</param>
        /// <param name="ModuleNode">CommunityServer.config CSModule node with the info</param>
        public void Init(CSApplication CSApp, System.Xml.XmlNode ModuleNode)
        {
            XmlAttribute attribute;

            CSApp.PreRenderPost += new CSPostEventHandler(this.OnPreRenderPost);

            // Get config. attributes
            attribute = ModuleNode.Attributes["showInRSS"];
            if (attribute != null)
            {
                showInRSS = (attribute.Value.ToLower() == "true" ? true : false);
            }
            attribute = ModuleNode.Attributes["showInWebPost"];
            if (attribute != null)
            {
                showInWebPost = (attribute.Value.ToLower() == "true" ? true : false);
            }
            attribute = ModuleNode.Attributes["backColor"];
            if (attribute != null)
            {
                backColor = attribute.Value.ToLower();
            }
            attribute = ModuleNode.Attributes["diggSkinMode"];
            if (attribute != null)
            {
                diggSkinMode = (attribute.Value.ToLower() == "normal" ? "normal" : "compact");
            }
        }

        #endregion

        #region Private Methods

        /// <summary>
        /// Called before rendering a post in the client's browser
        /// </summary>
        /// <param name="Content">Content to render</param>
        /// <param name="Args">CSPostEventArgs</param>
        private void OnPreRenderPost(IContent Content, CSPostEventArgs Args)
        {
            if ((Args.Target == PostTarget.Web && !showInWebPost) || 
                (Args.Target == PostTarget.Syndication && !showInRSS))
            {
                return;
            }

            if (Args.ApplicationType == ApplicationType.Weblog)
            {
                WeblogPost weblogPost = Content as WeblogPost;

                // Only to be shown in Web and/or syndication
                if (weblogPost != null && weblogPost.PostLevel == 1 &&
                    (Args.Target == PostTarget.Web || Args.Target == PostTarget.Syndication))
                {
                    weblogPost.FormattedBody = string.Format(
                        "{0}\n<script type=\"text/javascript\">digg_url='{1}';digg_title='{2}';digg_skin='{3}';digg_bgcolor='{4}';</script><script src='http://digg.com/tools/diggthis.js' type='text/javascript'></script>",
                        weblogPost.FormattedBody, 
                        Globals.FullPath(BlogUrls.Instance().Post(weblogPost)), 
                        weblogPost.Subject,
                        diggSkinMode,
                        backColor);
                }
            }
        }

        #endregion
    }
}
