//------------------------------------------------------------------------------
// <copyright company="Kartones.Net">
//     Copyleft (c) Kartones 2009
// </copyright> 
//------------------------------------------------------------------------------

using System;
using System.Xml;
using System.Collections.Generic;
using CommunityServer.Components;


namespace KartonesNet.Modules
{
    /// <summary>
    /// Custom Embedded Slideshows from Google Documents or Slideshare Module. 
    /// Checks for special tokens to embedd slideshows in posts/comments
    /// </summary>
    public class SlideshowsAddon : ICSModule
    {
        #region Fields

        private static List<ApplicationType> applications = new List<ApplicationType>();
        private static readonly string gdocvideoSubstitutionString =
            "<iframe src='http://docs.google.com/EmbedSlideshow?docid={0}' frameborder='0' width='410' height='342'></iframe>";
        private static readonly string slideshareSubstitutionString =
            "<object style='margin:0px' width='425' height='355'><param name='movie' value='http://static.slidesharecdn.com/swf/ssplayer2.swf?{0}&amp;rel=0' /><param name='allowFullScreen' value='true'/><param name='allowScriptAccess' value='always'/><embed src='http://static.slidesharecdn.com/swf/ssplayer2.swf?doc={0}&amp;rel=0' type='application/x-shockwave-flash' allowscriptaccess='always' allowfullscreen='true' width='425' height='355'></embed></object>";

        #endregion

        #region Class Constructor

        /// <summary>
        /// Class Constructor
        /// </summary>
        public SlideshowsAddon()
        {
        }

        #endregion

        #region ICSModule Methods

        /// <summary>
        /// Init Method. Called by CS when starting the module
        /// </summary>
        /// <param name="CSApp">CS Application starting the module</param>
        /// <param name="ModuleNode">CommunityServer.config CSModule node with the info</param>
        public void Init(CSApplication CSApp, System.Xml.XmlNode ModuleNode)
        {
            applications.Clear();
            
            CSApp.PreRenderPost += new CSPostEventHandler(this.OnPreRenderPost);
            
            XmlAttribute attribute = ModuleNode.Attributes["applications"];
            
            if (attribute != null)
            {
                string[] textArray = 
                    attribute.Value.Split(new char[] { ',', ';' }, StringSplitOptions.RemoveEmptyEntries);
                if ((textArray != null) && (textArray.Length > 0))
                {
                    foreach (string text in textArray)
                    {
                        applications.Add((ApplicationType)Enum.Parse(typeof(ApplicationType), text, true));
                    }
                }
                else
                {
                    applications.Add(ApplicationType.Weblog);
                }
            }
        }

        #endregion

        #region Private Methods

        /// <summary>
        /// Called before rendering a post in the client's browser
        /// </summary>
        /// <param name="Content">Content to render</param>
        /// <param name="Args">CSPostEventArgs</param>
        private void OnPreRenderPost(IContent Content, CSPostEventArgs Args)
        {
            if ((Content is Post) && applications.Contains(Args.ApplicationType))
            {
                foreach (TextPart textpart in Args.TextParts)
                {
                    if (textpart.Count > 1)
                    {
                        switch (textpart.Name.ToLower())
                        {
                            case "slideshare":
                                Content.FormattedBody = textpart.Replace(Content.FormattedBody,
                                    string.Format(slideshareSubstitutionString, textpart.Value));
                                break;
                            case "gdoc":
                                Content.FormattedBody = textpart.Replace(Content.FormattedBody,
                                    string.Format(gdocvideoSubstitutionString, textpart.Value));
                                break;
                        }
                    }
                }
            }
        }

        #endregion
    }
}
