//------------------------------------------------------------------------------
// <copyright company="Kartones.Net">
//     Copyleft (c) Kartones 2009
// </copyright> 
//------------------------------------------------------------------------------

using System;
using System.Xml;
using System.Collections.Generic;
using CommunityServer.Components;


namespace KartonesNet.Modules
{
    /// <summary>
    /// Custom Embedded Videos Module. Checks for special tokens to embedd videos in posts/comments
    /// </summary>
    public class VideosAddon : ICSModule
    {
        #region Fields

        private static List<ApplicationType> applications = new List<ApplicationType>();
        private static readonly string youtubeSubstitution =
            "<object width='435' height='365'><param name='movie' value='http://www.youtube.com/v/{0}&amp;rel=0&amp;fmt=18&amp;color1=ddddcc&amp;color2=eeeedd&amp;showinfo=0'></param><embed src='http://www.youtube.com/v/{0}&amp;rel=0&amp;fmt=18&amp;color1=ddddcc&amp;color2=eeeedd&amp;showinfo=0' type='application/x-shockwave-flash' width='435' height='365'></embed></object>";
        private static readonly string soapboxSubstitution =
            "<embed src='http://images.soapbox.msn.com/flash/soapbox1_1.swf' quality='high' width='435' height='365' wmode='transparent' type='application/x-shockwave-flash' pluginspage='http://macromedia.com/go/getflashplayer' flashvars='c=v&amp;v={0}'></embed>";
        private static readonly string googlevideoSubstitution =
            "<embed style='width:435px; height:365px;' id='VideoPlayback' type='application/x-shockwave-flash' src='http://video.google.com/googleplayer.swf?docId={0}' flashvars=''></embed>";
        private static readonly string gametrailersSubstitution =
            "<embed type='application/x-shockwave-flash' src='http://www.gametrailers.com/remote_wrap.php?mid={0}' width='480' height='392' play='true' loop='true' quality='high' AllowScriptAccess='never' />";

        #endregion

        #region Class Constructor

        /// <summary>
        /// Class Constructor
        /// </summary>
        public VideosAddon()
        {
        }

        #endregion

        #region ICSModule Methods

        /// <summary>
        /// Init Method. Called by CS when starting the module
        /// </summary>
        /// <param name="CSApp">CS Application starting the module</param>
        /// <param name="ModuleNode">CommunityServer.config CSModule node with the info</param>
        public void Init(CSApplication CSApp, System.Xml.XmlNode ModuleNode)
        {
            applications.Clear();
            
            CSApp.PreRenderPost += new CSPostEventHandler(this.OnPreRenderPost);
            
            XmlAttribute attribute = ModuleNode.Attributes["applications"];
            
            if (attribute != null)
            {
                string[] textArray = 
                    attribute.Value.Split(new char[] { ',', ';' }, StringSplitOptions.RemoveEmptyEntries);
                if ((textArray != null) && (textArray.Length > 0))
                {
                    foreach (string text in textArray)
                    {
                        applications.Add((ApplicationType)Enum.Parse(typeof(ApplicationType), text, true));
                    }
                }
                else
                {
                    applications.Add(ApplicationType.Weblog);
                }
            }
        }

        #endregion

        #region Private Methods

        /// <summary>
        /// Called before rendering a post in the client's browser
        /// </summary>
        /// <param name="Content">Content to render</param>
        /// <param name="Args">CSPostEventArgs</param>
        private void OnPreRenderPost(IContent Content, CSPostEventArgs Args)
        {
            if ((Content is Post) && applications.Contains(Args.ApplicationType))
            {
                foreach (TextPart textpart in Args.TextParts)
                {
                    if (textpart.Count > 1)
                    {
                        switch (textpart.Name.ToLower())
                        {
                            case "youtube":
                                Content.FormattedBody = textpart.Replace(Content.FormattedBody,
                                    string.Format(youtubeSubstitution, textpart.Value));
                                break;
                            case "gametrailers":
                                Content.FormattedBody = textpart.Replace(Content.FormattedBody,
                                    string.Format(gametrailersSubstitution, textpart.Value));
                                break;
                            case "soapbox":
                                Content.FormattedBody = textpart.Replace(Content.FormattedBody,
                                    string.Format(soapboxSubstitution, textpart.Value));
                                break;
                            case "googlevideo":
                                Content.FormattedBody = textpart.Replace(Content.FormattedBody,
                                    string.Format(googlevideoSubstitution, textpart.Value));
                                break;
                        }
                    }
                }
            }
        }

        #endregion
    }
}
