//------------------------------------------------------------------------------
// <copyright company="Kartones.Net">
//     Copyleft (c) Kartones 2009
// </copyright> 
//------------------------------------------------------------------------------

using System;
using System.Xml;
using Telligent.Tasks;
using CommunityServer.Components;

namespace KartonesNet.Tasks
{
    /// <summary>
    /// Custom CS Task that clears EventLog and Exceptions Report entries.
    /// Also cleans all but the lastest 'cs_statistics_Site' table entry, and empties 'cs_urls' and 'cs_referrals' tables.
    /// </summary>
    public class ClearLogsJob : ITask
    {
        #region Fields

        private int expirationDays = 30;
        private bool clearExceptions = false;

        #endregion

        #region Class Constructor

        /// <summary>
        /// Class Constructor
        /// </summary>
        public ClearLogsJob()
        {
        }

        #endregion

        #region ITask Methods

        /// <summary>
        /// Executes the task
        /// </summary>
        /// <param name="TaskNode">CommunityServer.config Task node with the info</param>
        void ITask.Execute(XmlNode TaskNode)
        {
            try 
            {
                expirationDays = int.Parse(TaskNode.Attributes["expirationDays"].Value); 
            }
            catch 
            { 
            }

            try
            {
                clearExceptions = bool.Parse(TaskNode.Attributes["clearExceptions"].Value);
            }
            catch
            {
            }

            SiteSettingsManager.IterateSiteSettings(new SiteSettingsListIterator(DeleteLogEntries));

            CommonDataProvider.Instance().CleanUnwantedStats();
        }

        #endregion

        #region Public Methods

        /// <summary>
        /// Deletes Log entries
        /// </summary>
        /// <param name="SettingsID">SettingsID</param>
        public void DeleteLogEntries(int SettingsID)
        {
            DateTime date = DateTime.Now.AddSeconds(-(expirationDays*86400));

            // Clear all eventLog entries older than expirationDays
            CommonDataProvider.Instance().ClearEventLog(date);

            if (clearExceptions)
            {
                // Clear all exceptions
                CommonDataProvider.Instance().DeleteExceptions(SettingsID, null, expirationDays);
            }
        }

        #endregion
    }
}
